package Bundle::Math::Calculus;
use strict;
use warnings;

$VERSION = '1.00';

1;

__END__

=head1 NAME

Bundle::Math::Calculus - A bundle to install various calculus related modules

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Math::Calculus'

=head1 CONTENTS

Math::Amoeba

Math::Algebra::Symbols

Math::Brent

Math::Derivative

Math::Integral::Romberg

Math::RungeKutta

Math::Sequence

Math::Series

Math::Symbolic

Math::Symbolic::Custom::CCompiler

Math::Systems

Math::Volume::Rotational

=head1 DESCRIPTION

This is a bundle of calculus related modules.

Please have a look at L<Bundle::Math>.

If you would like to see a specific module included in a future version of
this bundle, please send me an email or use rt.cpan.org.

=head1 AUTHOR

Steffen Mueller E<lt>bundlemath-module at steffen-mueller dot netE<gt>

=cut 
